@@ -5,31 +5,31 @@ import noolite
 class Tests(unittest.TestCase):
     def test_init_ch_type(self):
         with self.assertRaises(ValueError):
-            n = noolite.NooLite(channals="bla")
-            n = noolite.NooLite(idVendor="bla")
+            n = noolite.NooLite(channals="bla", tests=True)
+            n = noolite.NooLite(idVendor="bla", tests=True)
 
     def test_init_idVendor_type(self):
         with self.assertRaises(ValueError):
-            n = noolite.NooLite(idVendor="bla")
+            n = noolite.NooLite(idVendor="bla", tests=True)
 
     def test_init_idProduct_type(self):
         with self.assertRaises(ValueError):
-            n = noolite.NooLite(idProduct="bla")
+            n = noolite.NooLite(idProduct="bla", tests=True)
 
     def test_ch_str(self):
-        n = noolite.NooLite()
+        n = noolite.NooLite(tests=True)
         self.assertEqual(n.on("8"), 0)
 
     def test_ch_int(self):
-        n = noolite.NooLite()
+        n = noolite.NooLite(tests=True)
         self.assertEqual(n.off("8"), 0)
 
     def test_ch_negative(self):
-        n = noolite.NooLite()
+        n = noolite.NooLite(tests=True)
         self.assertRaises(noolite.NooLiteErr, n.on, -1)
 
     def test_ch_too_big(self):
-        n = noolite.NooLite()
+        n = noolite.NooLite(tests=True)
         self.assertRaises(noolite.NooLiteErr, n.on, 42)
 
 if __name__ == '__main__':
